Index: trunk/psLib/src/astronomy/psTime.c
===================================================================
--- trunk/psLib/src/astronomy/psTime.c	(revision 3114)
+++ trunk/psLib/src/astronomy/psTime.c	(revision 3182)
@@ -10,6 +10,6 @@
  *  @author Ross Harman, MHPCC
  *
- *  @version $Revision: 1.50 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2005-02-03 00:45:06 $
+ *  @version $Revision: 1.51 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2005-02-10 02:36:41 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -43,8 +43,8 @@
 
 /** Two times pi with double precision accuracy */
-#define TWOPI (2.0*M_PI)
+#define TWOPI (2.0*PS_PI)
 
 /** Conversion from radians to degrees */
-#define R2DEG = (180.0/M_PI)
+#define R2DEG = (180.0/PS_PI)
 
                 /** Maximum length of time string */
@@ -548,5 +548,5 @@
 
         t = 2000.0 + (mjd - 51544.03)/365.2422;
-        dut2ut1 = 0.022*sin(TWOPI*t) - 0.012*cos(TWOPI*t) - 0.006*sin(4.0*M_PI*t) + 0.007*cos(4.0*M_PI*t);
+        dut2ut1 = 0.022*sin(TWOPI*t) - 0.012*cos(TWOPI*t) - 0.006*sin(4.0*PS_PI*t) + 0.007*cos(4.0*PS_PI*t);
         result = dut->data.F64[0] + dut->data.F64[1]*(mjd - dut->data.F64[2]) - dut2ut1;
 
@@ -677,8 +677,8 @@
     }
 
     // Create output sphere and convert arcsec to radians (i.e. x/60/60*M_PI/180)
     output = psAlloc(sizeof(psSphere));
-    output->r = x * M_PI / 648000.0;
-    output->d = y * M_PI / 648000.0;
+    output->r = x * PS_PI / 648000.0;
+    output->d = y * PS_PI / 648000.0;
 
     return output;
@@ -677,8 +677,8 @@
     }
 
-    // Create output sphere and convert arcsec to radians (i.e. x/60/60*M_PI/180)
+    // Create output sphere and convert arcsec to radians (i.e. x/60/60*PS_PI/180)
     output = psAlloc(sizeof(psSphere));
